@@ -1,7 +1,7 @@
 """
 Type annotations for codepipeline service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/type_defs/)
 
 Usage::
 
@@ -114,17 +114,23 @@ __all__ = (
     "JobTypeDef",
     "JobWorkerExecutorConfigurationTypeDef",
     "LambdaExecutorConfigurationTypeDef",
+    "ListActionExecutionsInputListActionExecutionsPaginateTypeDef",
     "ListActionExecutionsInputRequestTypeDef",
     "ListActionExecutionsOutputTypeDef",
+    "ListActionTypesInputListActionTypesPaginateTypeDef",
     "ListActionTypesInputRequestTypeDef",
     "ListActionTypesOutputTypeDef",
+    "ListPipelineExecutionsInputListPipelineExecutionsPaginateTypeDef",
     "ListPipelineExecutionsInputRequestTypeDef",
     "ListPipelineExecutionsOutputTypeDef",
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
     "ListPipelinesInputRequestTypeDef",
     "ListPipelinesOutputTypeDef",
+    "ListTagsForResourceInputListTagsForResourcePaginateTypeDef",
     "ListTagsForResourceInputRequestTypeDef",
     "ListTagsForResourceOutputTypeDef",
     "ListWebhookItemTypeDef",
+    "ListWebhooksInputListWebhooksPaginateTypeDef",
     "ListWebhooksInputRequestTypeDef",
     "ListWebhooksOutputTypeDef",
     "OutputArtifactTypeDef",
@@ -832,6 +838,15 @@ LambdaExecutorConfigurationTypeDef = TypedDict(
     },
 )
 
+ListActionExecutionsInputListActionExecutionsPaginateTypeDef = TypedDict(
+    "ListActionExecutionsInputListActionExecutionsPaginateTypeDef",
+    {
+        "pipelineName": str,
+        "filter": NotRequired["ActionExecutionFilterTypeDef"],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListActionExecutionsInputRequestTypeDef = TypedDict(
     "ListActionExecutionsInputRequestTypeDef",
     {
@@ -851,6 +866,15 @@ ListActionExecutionsOutputTypeDef = TypedDict(
     },
 )
 
+ListActionTypesInputListActionTypesPaginateTypeDef = TypedDict(
+    "ListActionTypesInputListActionTypesPaginateTypeDef",
+    {
+        "actionOwnerFilter": NotRequired[ActionOwnerType],
+        "regionFilter": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListActionTypesInputRequestTypeDef = TypedDict(
     "ListActionTypesInputRequestTypeDef",
     {
@@ -869,6 +893,14 @@ ListActionTypesOutputTypeDef = TypedDict(
     },
 )
 
+ListPipelineExecutionsInputListPipelineExecutionsPaginateTypeDef = TypedDict(
+    "ListPipelineExecutionsInputListPipelineExecutionsPaginateTypeDef",
+    {
+        "pipelineName": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPipelineExecutionsInputRequestTypeDef = TypedDict(
     "ListPipelineExecutionsInputRequestTypeDef",
     {
@@ -887,6 +919,13 @@ ListPipelineExecutionsOutputTypeDef = TypedDict(
     },
 )
 
+ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
@@ -904,6 +943,14 @@ ListPipelinesOutputTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceInputListTagsForResourcePaginateTypeDef = TypedDict(
+    "ListTagsForResourceInputListTagsForResourcePaginateTypeDef",
+    {
+        "resourceArn": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListTagsForResourceInputRequestTypeDef = TypedDict(
     "ListTagsForResourceInputRequestTypeDef",
     {
@@ -935,6 +982,13 @@ ListWebhookItemTypeDef = TypedDict(
     },
 )
 
+ListWebhooksInputListWebhooksPaginateTypeDef = TypedDict(
+    "ListWebhooksInputListWebhooksPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListWebhooksInputRequestTypeDef = TypedDict(
     "ListWebhooksInputRequestTypeDef",
     {
